==> firebase_lumberdash-1.0.1.tar.gz: README.md <==
# firebase_lumberdash

Plugin for [lumberdash](https://github.com/jorgecoca/lumberdash)

It sends your logs to [Firebase Analytics](https://firebase.google.com/docs/analytics).

## How to use

Add `firebase_lumberdash` to your dependencies. Then pass an instance of `FirebaseLumberdash` to `lumberdash`:

```dart
import 'package:lumberdash/lumberdash.dart';
import 'package:firebase_analytics/firebase_analytics.dart';
import 'package:firebase_lumberdash/firebase_lumberdash.dart';

void main() {
  putLumberdashToWork(
    withClient: FirebaseLumberdash(
      firebaseAnalyticsClient: FirebaseAnalytics(),
      loggerName: 'FirebaseLumberdash',
      environment: 'development',
      releaseVersion: '1.0.0',
    ),
  );
  logWarning('Hello Warning');
  logFatal('Hello Fatal!');
  logMessage('Hello Message!');
  logError(Exception('Hello Error'));
}
```

## License

```
MIT License

Copyright (c) 2019 Felix Angelov

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```

==> firebase_lumberdash-2.1.0.tar.gz: README.md <==
# firebase_lumberdash

Plugin for [lumberdash](https://github.com/jorgecoca/lumberdash)

It sends your logs to [Firebase Analytics](https://firebase.google.com/docs/analytics).

## How to use

Add `firebase_lumberdash` to your dependencies. Then pass an instance of `FirebaseLumberdash` to `lumberdash`:

```dart
import 'package:lumberdash/lumberdash.dart';
import 'package:firebase_analytics/firebase_analytics.dart';
import 'package:firebase_lumberdash/firebase_lumberdash.dart';

void main() {
  putLumberdashToWork(
    withClients: [FirebaseLumberdash(
      firebaseAnalyticsClient: FirebaseAnalytics(),
      loggerName: 'FirebaseLumberdash',
      environment: 'development',
      releaseVersion: '1.0.0',
    )],
  );
  logWarning('Hello Warning');
  logFatal('Hello Fatal!');
  logMessage('Hello Message!');
  logError(Exception('Hello Error'));
}
```

## License

```
MIT License

Copyright (c) 2019 Felix Angelov

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```
